==> WebCore-125.8.12.tar.gz: WebCore-125.8.12/kwq/WebCoreImageRendererFactory.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#import <Cocoa/Cocoa.h>

@protocol WebCoreImageRenderer;

@protocol WebCoreImageRendererFactory

- (id <WebCoreImageRenderer>)imageRenderer;
- (id <WebCoreImageRenderer>)imageRendererWithMIMEType:(NSString *)MIMEType;
- (id <WebCoreImageRenderer>)imageRendererWithBytes:(const void *)bytes length:(unsigned)length;
- (id <WebCoreImageRenderer>)imageRendererWithBytes:(const void *)bytes length:(unsigned)length MIMEType:(NSString *)MIMEType;
- (id <WebCoreImageRenderer>)imageRendererWithSize:(NSSize)size;
- (id <WebCoreImageRenderer>)imageRendererWithName:(NSString *)name;
- (NSArray *)supportedMIMETypes;

@end

@interface WebCoreImageRendererFactory : NSObject
{
}

+ (WebCoreImageRendererFactory *)sharedFactory;
@end

@interface WebCoreImageRendererFactory (SubclassResponsibility) <WebCoreImageRendererFactory>
@end

==> WebCore-146.1.tar.gz: WebCore-146.1/kwq/WebCoreImageRendererFactory.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#import <Cocoa/Cocoa.h>

@protocol WebCoreImageRenderer;

@protocol WebCoreImageRendererFactory

- (id <WebCoreImageRenderer>)imageRenderer;
- (id <WebCoreImageRenderer>)imageRendererWithMIMEType:(NSString *)MIMEType;
- (id <WebCoreImageRenderer>)imageRendererWithBytes:(const void *)bytes length:(unsigned)length;
- (id <WebCoreImageRenderer>)imageRendererWithBytes:(const void *)bytes length:(unsigned)length MIMEType:(NSString *)MIMEType;
- (id <WebCoreImageRenderer>)imageRendererWithSize:(NSSize)size;
- (id <WebCoreImageRenderer>)imageRendererWithName:(NSString *)name;
- (NSArray *)supportedMIMETypes;
- (int)CGCompositeOperationInContext:(CGContextRef)context;
- (void)setCGCompositeOperation:(int)op inContext:(CGContextRef)context;
- (void)setCGCompositeOperationFromString:(NSString *)op inContext:(CGContextRef)context;

@end

@interface WebCoreImageRendererFactory : NSObject
{
}

+ (WebCoreImageRendererFactory *)sharedFactory;
@end

@interface WebCoreImageRendererFactory (SubclassResponsibility) <WebCoreImageRendererFactory>
@end
